use serde::{Serialize, Deserialize};

#[derive(Serialize, Deserialize)]
pub struct Config {
  pub proto: String,
  pub domain: String,
  pub basepath: String,
}

impl Config {
  pub fn default() -> Config {
    Config {
      proto: "https".to_owned(),
      domain: "localhost".to_owned(),
      basepath: "".to_owned(),
    }
  }
  pub fn load(path: &str) -> Result<Config, String> {
    match std::fs::read_to_string(path) {
      Ok(text) => match serde_json::from_str(&text) {
        Ok(cfg) => Ok(cfg),
        Err(e) => Err(format!("{}", e)),
      },
      Err(e) => Err(format!("{}", e)),
    }
  }

  pub fn get_baseurl(&self) -> String {
    let mut p =
        format!("{}://{}/{}", self.proto, self.domain, self.basepath);
    while p.ends_with("/") { p.pop(); }
    return p;
  }
}
