use lazy_static::lazy_static;
use regex::Regex;

pub struct Id {
  pub name: String,
  pub host: Option<String>,
}
pub struct Profile {
  pub name: String,
  pub private: bool,
}

// hello@world.com -> Id {hello, world.com}
impl Id {
  pub fn parse(v: &str) -> Result<Id, String> {
    lazy_static! {
      static ref RE: Regex =  Regex::new(r"^([A-Za-z0-9_]+)(?:@([A-Za-z0-9\-\.]+))?$").unwrap();
    }
    match RE.captures(v) {
      Some(caps) => Ok(Id {
        name: caps.get(1).unwrap().as_str().to_owned(),
        host: caps.get(2).map_or(None, |m| Some(m.as_str().to_owned())),
      }),
      None => Err("invalid idstr".to_owned()),
    }
  }
  pub fn local(name: &str) -> Id {
    Id {name: name.to_owned(), host: None}
  }

  fn to_string(&self, default_host: &str) -> String {
    format!("{}@{}", self.name, self.host.as_deref().unwrap_or(default_host))
  }
}
