use rocket::{get, Responder, State};
use rocket::serde::json::Json;

use crate::apub;
use crate::ctx::db;
use crate::ctx::user;

use crate::ctx::Ctx;

#[derive(Responder)]
pub enum Response {
  #[response(status = 200, content_type = "json")]
  Found(Json<apub::Actor>),

  #[response(status = 404)]
  Missing(String),

  #[response(status = 500)]
  InternalError(String),
}

#[get("/<name>")]
pub fn main(ctx: &State<Ctx>, name: &str) -> Response {
  match ctx.db.get_profile(&user::Id::local(name)) {
    Ok(profile) => Response::Found(Json(new(ctx, name, &profile))),
    Err(db::ReadError::Missing) => Response::Missing(format!("unknown actor: {}", name)),
    Err(db::ReadError::Internal(msg)) =>
        Response::InternalError(format!("internal error: {}", msg)),
  }
}

fn new(ctx: &Ctx, id: &str, p: &user::Profile) -> apub::Actor {
  let idurl = format!("{}/{}", ctx.cfg.get_baseurl(), id);
  apub::Actor {
    context: apub::Actor::default_context(),
    id     : idurl.clone(),
    type_  : "Person".to_owned(),
    preferred_username: id.to_owned(),
    inbox  : format!("{}/inbox", idurl),
    outbox : format!("{}/outbox", idurl),
    public_key: apub::actor::PublicKey {
      id: format!("{}#main-key", idurl),
      owner: idurl,
      public_key_pem: "".to_owned(),
    },
  }
}
